pub struct SqliteDriver { /* private fields */ }Expand description
The sole SQLite driver, configured with admitted domains and preopened storage.
Implementations
Sourceimpl SqliteDriver
impl SqliteDriver
Sourcepub fn new(domains: DomainCatalog, stores: PreopenedStores) -> Self
pub fn new(domains: DomainCatalog, stores: PreopenedStores) -> Self
Constructs the capsule driver.
Sourcepub fn library(
self,
locator: &StorageLocator,
) -> Result<RelationSiteLib, SiteError>
pub fn library( self, locator: &StorageLocator, ) -> Result<RelationSiteLib, SiteError>
Constructs the canonical loadable site library.
Errors
Returns a registration refusal when the canonical driver manifest is invalid.